@@ -1,4 +1,4 @@
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
@@ -12,7 +12,7 @@ from typing_extensions import Protocol
 # in their own environment
 from . import safe_json, tests, type_variable_operators
 from .generic import Generic
-from .refinement import none_throws, assert_is_instance, safe_cast
+from .refinement import assert_is_instance, none_throws, safe_cast
 
 
 __all__ = [
@@ -20,9 +20,10 @@ __all__ = [
     "DecoratorFactory",
     "Generic",
     "JSON",
-    "ListVariadic",
     "none_throws",
+    "override",
     "ParameterSpecification",
+    "ReadOnly",
     "safe_cast",
     "safe_json",
     "tests",
@@ -78,7 +79,7 @@ class ParameterSpecification(list):
         pass
 
 
-def ListVariadic(name) -> object:
+def TypeVarTuple(name: str) -> object:
     return Any
 
 
@@ -86,9 +87,15 @@ _A = TypeVar("_A", bound=int)
 _B = TypeVar("_B", bound=int)
 _T1 = TypeVar("_T1")
 _T2 = TypeVar("_T2")
-_Ts = ListVariadic("_Ts")
+_Ts = TypeVarTuple("_Ts")
 _P = ParameterSpecification("_P")
 
+T = TypeVar("T", bound=Callable[..., object])
+
+
+def override(func: T) -> T:
+    return func
+
 
 class DecoratorFactory(Protocol):
     """Usable as a return type for simple decorator factories"""
@@ -121,14 +128,6 @@ class Product(Generic[_Ts], int):
     pass
 
 
-class TypeVarTuple:
-    def __init__(
-        self,
-        name: str,
-    ) -> None:
-        pass
-
-
 class Unpack(Generic[_T]):
     pass
 
@@ -141,8 +140,9 @@ class BroadcastError(Generic[_T1, _T2]):
     pass
 
 
-_Rs = TypeVarTuple("_Rs")
+class Compose(Generic[_Ts]):
+    pass
 
 
-class Compose(Generic[_Rs]):
+class ReadOnly(Generic[_T]):
     pass
